Skip to contents

This function calculate Youden index estimator, their standard error estimated and a confidence interval in a traverse or Cross-sectional study.

Usage

ebdt_you(s1, r1, s0, r0, conflev = 0.95, digits = 3)

Arguments

s1

Non-negative numeric. TP - True positive (cases correctly classified as +).

r1

Non-negative numeric. FP - False positives (controls classified as +).

s0

Non-negative numeric. FN - False negatives (cases classified as -).

r0

Non-negative numeric. TN - True negatives (controls classified as -).

conflev

Confidence level (0,1). Default 0.95.

digits

Integer. Number of decimal places. Default 3.

Value

list with: - YoudenIndex: Youden Index estimation J = Se + Sp - 1 - StdError: standard error of J by delta method assuming independence of cases and controls - CI: approximate normal confidence interval for J

Details

Evaluating of Binary Diagnostic Test (EBDT)

This function calculates the Youden Index, standard error & Agresti-Coull CI

- Corrección Haldane–Anscombe *in pairs* if there are zeros: (s1,s0) and/or (r1,r0), +0.5 is added to both cells of the pair. - EE(J) is calculated as: sqrt( Se*(1-Se)/n_cases + Sp*(1-Sp)/n_ctrls ), valid under independence between cases and controls (common in diagnostic studies). - IC is constructed with normal approximation: J ± z * EE(J).

References

Agresti, A., (2002). Categorical Data Analysis. John Wiley and Sons, New York.

Agresti, A., Coull, B.A., (1998). Approximate is better than ‘exact’ for interval estimation of binomial proportions. The American Statistician, 52:119 – 126.

Montero-Alonso, M.Á.(2010). Intervalos de confianza y contrastes de hipótesis para parámetros de tests diagnósticos binarios, http://hdl.handle.net/10481/4879

Pepe, M. S. (2003). The statistical evaluation of medical tests for classification and prediction. Oxford University Press.

Zhou, X.-H., Obuchowski, N. A., y McClish, D. K. (2011). Statistical Methods in Diagnostic Medicine (2.ª ed.). John Wiley & Sons.

Examples

ebdt_you(40, 5, 10, 45)
#> 
#>  Y O U D E N  I N D E X 
#> ------------------------
#> 
#> Youden index estimated is: 0.7 
#> Standard error estimated is: 0.071 
#> 95 %CI for Youden index is [ 0.561 ; 0.839 ]
#>